# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
#
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
#
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the License.
#
# Authors:
# -----------------------------------------------------------------------------
#	Rueen Fiez <rueenfiez@gmail.com>
#	Vincent Lam <vlam6@learn.senecac.on.ca>
#	Armen Zambrano Gasparnian <armenzg@gmail.com>
# -----------------------------------------------------------------------------
#
# Alternatively, the contents of this file may be used under the terms of
# either the GNU General Public License Version 2 or later (the "GPL"), or
# the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
#
# ***** END LICENSE BLOCK *****

# VERSION:
# ==============================
# version 0.2.3
# ==============================

import re
import os
import Parser
from Parser import DTDParser
from Parser import PropertiesParser

import sys

#try to read a DTD file and attempt to make changes to a "word"
class Tool:
	 #constructor
	 def __init__(self):
		  self.data = []
		  
	 # DESCRIPTION
	 # callback() is passed a string to be translated. It is responsible for changing all parser.contents
	 # values. We insert the translation rules in here via regular expressions. This function needs to be
	 # optomized since their could be hundreds of translations, thus resulting in a bloated callback() function.
	 def callback(self, instring):
		  return re.sub(r'(.*)([Cc])olor', r'\1\2olour', instring)

	 # DESCRIPTION
	 # translate() uses the DTDParser and PropertiesParser from the Parser.py class to
	 # parse each .dtd and .properties file in the given directory. Its contents
	 # are then passed into our callback() function string by string and changed in their.
	 def translate(self, node):
		  dtdParser = DTDParser()
		  propParser = PropertiesParser()
		  if(node.endswith('.dtd')):
			  f = open(node+'.bak','w')
			  dtdParser.read(node)
			  f.write((t.callback(dtdParser.contents)).encode("utf-8"))
			  # Use for DEBUGGING
			  #print dtdParser.contents
			  f.close()
		  elif(node.endswith('.properties')):
			  f = open(node+'.bak','w')
			  propParser.read(node)
			  f.write((t.callback(propParser.contents)).encode("utf-8"))
			  # Use for DEBUGGING
			  #print propParser.contents
			  f.close()

##		  dtdParser = DTDParser()
##		  propParser = PropertiesParser()
##		  if(node.endswith('.dtd'))

	 # DESCRIPTION
	 # process() is the function responsible for actually "walking" a
	 # given directory. It contains the logic used to see if each item in the folder
	 # is either a "file" or a "directory".
	 def process(self, cwd):
		  directories = [cwd]
		  while len(directories) > 0:
			  directory = directories.pop()
			  for name in os.listdir(directory):
				  fullpath = os.path.join(directory,name)
				  if os.path.isfile(fullpath):
					  # Use for DEBUGGING
					  print fullpath
					  t.translate(fullpath)
				  elif os.path.isdir(fullpath):
					  directories.append(fullpath)
					
##	      directories = [cwd]
##	      while len(directories) > 0:
##                     print 'hi'
##		while len(directories) > 0:
##			directory = directories.pop()
##			for name in os.listdir(directory):
##				fullpath = os.path.join(directory,name)
##				if os.path.isfile(fullpath):
##					print fullpath                # That's a file. Do something with it.
##					processfiles(fullpath)
##			elif os.path.isdir(fullpath):
##				directories.append(fullpath)  # It's a directory, store it. 

if __name__ == '__main__':
	 
	 # ################################################## #
	 # Code below was our original "main" code. Good for quick & dirty testing
	 
	 # Original #
	 #t = Tool()
	 #t.process('en-GB')
	 #print raw_input("press Return>")
	 # Original #
	 # ################################################## #

	 t = Tool()
	 # Parse command line arguments
	 locale1 = raw_input("Enter a localization (eg; en-GB)\nPath: ")
	 # Some input validation
	 if len(locale1) >= 3:
	 	 t.process(locale1)
	 	 print raw_input("\nTranslation(s) complete. Press ENTER to exit...>")
	 else:
	 	 print "\nNeed to input a valid localization path!"
		
		
	 
	 
